==> haskell-time-manager-0.0.1-89-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-time-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 time-manager
version:              0.0.1
visibility:           public
id:                   time-manager-0.0.1-3DkrMliwj9xJZbJg5X2r3Q
key:                  time-manager-0.0.1-3DkrMliwj9xJZbJg5X2r3Q
license:              MIT
maintainer:           kazu@iij.ad.jp
author:               Michael Snoyman and Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Scalable timer
description:          Scalable timer functions provided by a timer manager.
category:             System
abi:                  ea01297d176603f6ea000d26ec29e49c
exposed:              True
exposed-modules:      System.TimeManager
import-dirs:          /usr/lib/ghc-9.4.8/site-local/time-manager-0.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/time-manager-0.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/time-manager-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.4.8/time-manager-0.0.1
hs-libraries:         HStime-manager-0.0.1-3DkrMliwj9xJZbJg5X2r3Q
depends:
    auto-update-0.1.6-BP7ZhxcIenAIOTU8CTkm3t base-4.17.2.1
    unliftio-0.2.25.1-CSkQ6WBjw9j80OvsxjG0yH

haddock-interfaces:
    /usr/share/doc/haskell-time-manager/html/time-manager.haddock

haddock-html:         /usr/share/doc/haskell-time-manager/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-time-manager-0.0.1-90-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-time-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 time-manager
version:              0.0.1
visibility:           public
id:                   time-manager-0.0.1-7DlF1GZhUi43WkwEsXDtZ7
key:                  time-manager-0.0.1-7DlF1GZhUi43WkwEsXDtZ7
license:              MIT
maintainer:           kazu@iij.ad.jp
author:               Michael Snoyman and Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Scalable timer
description:          Scalable timer functions provided by a timer manager.
category:             System
abi:                  73dcccd0c566c9b6478636908a6536f6
exposed:              True
exposed-modules:      System.TimeManager
import-dirs:          /usr/lib/ghc-9.4.8/site-local/time-manager-0.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/time-manager-0.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/time-manager-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.4.8/time-manager-0.0.1
hs-libraries:         HStime-manager-0.0.1-7DlF1GZhUi43WkwEsXDtZ7
depends:
    auto-update-0.1.6-ImzSmIgtqtK5NclgP8vMHq base-4.17.2.1
    unliftio-0.2.25.1-LoveZ8ajQHRGyZYXvS1EQ2

haddock-interfaces:
    /usr/share/doc/haskell-time-manager/html/time-manager.haddock

haddock-html:         /usr/share/doc/haskell-time-manager/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
